import { CharacterRigR6 } from "@rbxts/character-promise"

/**
 * The Model component.
 *
 * Provides a reference to the {@link PVInstance} that represents the attached
 * entity.
 */
export interface Model {
	model?: PVInstance
}

/**
 * The Transform component.
 *
 * Provides a reference {@link CFrame} that represents the world transform of
 * the attached entity.
 */
export interface Transform {
	cframe: CFrame,
	_doNotReconcile?: true
}


/**
 * The Health component.
 *
 * Holds health information including health and regeneration.
 * Regen is health restored per second.
 */
export interface Health {
	health: number,
	maxHealth: number,
	regeneration: number
}

/**
 * The Damage component.
 *
 * Holds health-reduction information.
 */
export interface Damage {
	damage: number
}

/**
 * The PlayerCharacter component.
 * 
 * Holds the Character rig, Humanoid, and Player.
 */
export interface PlayerCharacter {
	character: CharacterRigR6,
	humanoid: Humanoid,
	player: Player,
	equippedTool?: Tool
}

/**
 * The Lifetime component.
 * 
 * Holds the time it was spawned at, how long it should last, and the time elapsed.
 */
export interface Lifetime {
	spawnedAt: number,
	length: number,
	elapsed: number
}